@@ -192,13 +192,13 @@ def rmshadows(humfile, sonpath, win=31, shadowmask=0, doplot=1):
     shape_port = np.squeeze(meta['shape_port'])
     if shape_port!='':
        #port_fp = np.memmap(sonpath+base+'_data_port_la.dat', dtype='float32', mode='r', shape=tuple(shape_port))
-       with open(os.path.normpath(os.path.join(sonpath,base+'_data_port_l.dat')), 'r') as ff:
+       with open(os.path.normpath(os.path.join(sonpath,base+'_data_port_la.dat')), 'r') as ff:
           port_fp = np.memmap(ff, dtype='float32', mode='r', shape=tuple(shape_port))
 
     shape_star = np.squeeze(meta['shape_star'])
     if shape_star!='':
        #star_fp = np.memmap(sonpath+base+'_data_star_la.dat', dtype='float32', mode='r', shape=tuple(shape_star))
-       with open(os.path.normpath(os.path.join(sonpath,base+'_data_star_l.dat')), 'r') as ff:
+       with open(os.path.normpath(os.path.join(sonpath,base+'_data_star_la.dat')), 'r') as ff:
           star_fp = np.memmap(ff, dtype='float32', mode='r', shape=tuple(shape_star))
 
     dist_m = np.squeeze(meta['dist_m'])
